/**
 * Configure Service SDK
 *
 * @description 负责处理配置中心配置
 *
 */

const RMDB = require('rmdb')
const Sign = require('@4a/sign')
const HTTP = require('./lib/http')

function generate(key) {
    const [app, mod, name] = key.split(':')
    return { app, mod, name }
}

module.exports = ({ appId, appSecret, redis, baseURL, debug = false }) => {
    const rmdb = RMDB(redis)
    const http = HTTP(baseURL, debug)
    const sign = new Sign({ appId, appSecret })
    const PREFIX = 'app:configured'

    class Configure {
        constructor(key, timeout = 300) {
            this.key = key
            this.timeout = timeout
            this.app = generate(key)
            this.app = sign.append(this.app)
            this.rmdb = rmdb.src(PREFIX, this.key)
                .keep(this.timeout)
                .from(() => http.get(this.app))
        }

        get() {
            return this.rmdb.get()
        }
    }

    return Configure
}
